@@ -10,17 +10,17 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-3.10.0-1062.18.1.el7.src.rpm ]
+if [ ! -r kernel-3.10.0-1127.el7.src.rpm ]
 then
-    wget http://vault.centos.org/centos/7/updates/Source/SPackages/kernel-3.10.0-1062.18.1.el7.src.rpm || die "Can't download source package."
+    wget http://vault.centos.org/centos/7/os/Source/SPackages/kernel-3.10.0-1127.el7.src.rpm || die "Can't download source package."
 fi
-LANG=C rpm --checksig kernel-3.10.0-1062.18.1.el7.src.rpm | grep -F ': rsa sha1 (md5) pgp md5 OK' || die "Can't verify signature."
-rpm -ivh kernel-3.10.0-1062.18.1.el7.src.rpm || die "Can't install source package."
+LANG=C rpm --checksig kernel-3.10.0-1127.el7.src.rpm | grep -F ': rsa sha1 (md5) pgp md5 OK' || die "Can't verify signature."
+rpm -ivh kernel-3.10.0-1127.el7.src.rpm || die "Can't install source package."
 
 cd ~/rpmbuild/SOURCES/ || die "Can't chdir to ~/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.6-20200413.tar.gz ]
+if [ ! -r ccs-patch-1.8.7-20200505.tar.gz ]
 then
-    wget -O ccs-patch-1.8.6-20200413.tar.gz 'https://osdn.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.6-20200413.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.7-20200505.tar.gz 'https://osdn.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.7-20200505.tar.gz' || die "Can't download patch."
 fi
 
 cd ~/rpmbuild/SPECS/ || die "Can't chdir to ~/rpmbuild/SPECS/ ."
@@ -28,16 +28,16 @@ cp -p kernel.spec ccs-kernel.spec || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
 --- ccs-kernel.spec
 +++ ccs-kernel.spec
-@@ -5,7 +5,7 @@
+@@ -3,7 +3,7 @@
  
- %define dist .el7
+ Summary: The Linux kernel
  
 -# % define buildid .local
-+%define buildid _tomoyo_1.8.6p2
++%define buildid _tomoyo_1.8.7
  
  # For a kernel released for public testing, released_kernel should be 1.
  # For internal testing builds during development, it should be 0.
-@@ -325,7 +325,7 @@
+@@ -322,7 +322,7 @@ AutoReq: no\
  AutoProv: yes\
  %{nil}
  
@@ -46,7 +46,7 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -678,13 +678,13 @@
+@@ -675,13 +675,13 @@ This is required to use SystemTap with %
  %package %{?1:%{1}-}devel\
  Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
  Group: System Environment/Kernel\
@@ -64,18 +64,18 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -796,6 +796,10 @@
+@@ -793,6 +793,10 @@ ApplyOptionalPatch debrand-single-cpu.pa
  ApplyOptionalPatch debrand-rh_taint.patch
  ApplyOptionalPatch debrand-rh-i686-cpu.patch
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.6-20200413.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.8.7-20200505.tar.gz
 +patch -sp1 < patches/ccs-patch-3.10-centos-7.diff
 +
  # Any further pre-build tree manipulations happen here.
  
  chmod +x scripts/checkpatch.pl
-@@ -834,6 +838,17 @@
+@@ -831,6 +835,17 @@ done
  for i in *.config
  do
    mv $i .config
